/*
 * Inkscape::XML::TransactionLogger - logs changes for transactions
 *
 * Copyright 2005 MenTaLguY <mental@rydia.net>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * See the file COPYING for details.
 *
 */

#ifndef SEEN_INKSCAPE_XML_TRANSACTION_LOGGER_H
#define SEEN_INKSCAPE_XML_TRANSACTION_LOGGER_H

#include "xml/node-observer.h"

namespace Inkscape {
namespace XML {
class Event;
}
}


namespace Inkscape {

namespace XML {

class Session;

class TransactionLogger : public NodeObserver {
public:
    virtual Session &session()=0;
};

}

}

#endif
/*
  Local Variables:
  mode:c++
  c-file-style:"stroustrup"
  c-file-offsets:((innamespace . 0)(inline-open . 0))
  indent-tabs-mode:nil
  fill-column:99
  End:
*/
// vim: filetype=c++:expandtab:shiftwidth=4:tabstop=8:softtabstop=4 :
